@@ -28,12 +28,7 @@ ParallelTest = function(nboot,y,obsTest,minRank)
 {
 nreps.list <- sapply(1:nboot, list)
 n = length(y)
-chk <- Sys.getenv("_R_CHECK_LIMIT_CORES_", "")
-if (nzchar(chk) && chk == "TRUE") {
-  n.cores <- 2L
-} else {
-  n.cores <- parallel::detectCores()
-}
+n.cores <- 2L
 clust <- parallel::makeCluster(n.cores)
 LRVec = rep(0,nboot)
 temp <- parallel::parLapply(clust,nreps.list,LPtest,n,mean(log(y)),sd(log(y)),minRank)
